# lexibase

SQLite persistence for `lingpy.Wordlist` and a bridge from `lingpy` to Edictor.

[![Build Status](https://travis-ci.org/lingpy/lexibase.svg?branch=master)](https://travis-ci.org/lingpy/lexibase)
[![codecov](https://codecov.io/gh/lingpy/lexibase/branch/master/graph/badge.svg)](https://codecov.io/gh/lingpy/lexibase)
[![PyPI](https://img.shields.io/pypi/v/lexibase.svg)](https://pypi.org/project/lexibase)
